@@ -3,7 +3,7 @@ use cc;
 fn main() {
     let mut build = cc::Build::new();
     let build = build.file("csrc/wfc.c");
-    let build = build.include("csrc/");
+    let build = build.include("wfc/");
 
     build.compile("wfc");
 }
